@@ -1,6 +1,8 @@
 import os
 import sys
 import time
+import shutil
+import subprocess
 from itertools import permutations
 import pickle
 from pydub import AudioSegment
@@ -47,6 +49,14 @@ def create_dir(dir_path):
         os.makedirs(dir_path)
 
 
+def remove_dir(dir_path):
+    if os.path.exists(dir_path):
+        try:
+            shutil.rmtree(dir_path)
+        except OSError as e:
+            print("Error: %s : %s" % (dir_path, e.strerror))
+
+
 def create_overlapping_signal(signal1, signal2, read=False):
     '''
     Mix two signals in one
@@ -196,19 +206,29 @@ def clock():
     try:
         return time.perf_counter()  # Python 3
     except:
-        return time.clock() # Python 2
+        return time.clock()  # Python 2
 
 
 class Timer(object):
     # Begin of `with` block
-    def __enter__(self):
+    def __enter__(self, granularity='s'):
+        '''
+        :param granularity: can be s - seconds, m - minuts, h - hours
+        :return:
+        '''
+        self.granularity = granularity
         self.start_time = clock()
         self.end_time = None
         return self
 
     # End of `with` block
     def __exit__(self, exc_type, exc_value, tb):
-        self.end_time = clock()
+        if self.granularity == 'm':
+            self.end_time = clock() / 60
+        elif self.granularity == 'h':
+            self.end_time = (clock() / 60) / 60
+        else:
+            self.end_time = clock()
 
     def elapsed_time(self):
         """Return elapsed time in seconds"""
@@ -218,3 +238,15 @@ class Timer(object):
         else:
             return self.end_time - self.start_time
 
+
+def run_cmd(args_list):
+    """
+    run linux commands
+    """
+    # import subprocess
+    print('Running system command: {0}'.format(' '.join(args_list)))
+    proc = subprocess.Popen(args_list, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+    s_output, s_err = proc.communicate()
+    s_return = proc.returncode
+
+    return s_return, s_output, s_err
